==> vss-ui-4.141.4.tgz: package/Components/Header/Header.js <==
import * as tslib_1 from "tslib";
import "../../FabricInit";
import * as React from "react";
import { HeaderCommandBar } from "../HeaderCommandBar/HeaderCommandBar";
import { VssIcon } from '../../VssIcon';
import { BaseComponent, css } from "office-ui-fabric-react/lib/Utilities";
import { TabProviderContext } from "../Tabs/TabProviderContext";
var Header = /** @class */ (function (_super) {
    tslib_1.__extends(Header, _super);
    function Header() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Header.prototype.render = function () {
        var _this = this;
        return React.createElement(TabProviderContext.Consumer, null, function (tabProviderContext) {
            var _a = _this.props, title = _a.title, kicker = _a.kicker, titleSize = _a.titleSize, onRenderTitle = _a.onRenderTitle, titleIconProps = _a.titleIconProps, viewItems = _a.viewItems, className = _a.className;
            var commandBarItems = _this.props.commandBarItems || tabProviderContext.commandBarItems;
            // Render the title as text, or override with custom rendering logic
            var titleElement;
            if (onRenderTitle) {
                titleElement = onRenderTitle();
            }
            else {
                titleElement = (React.createElement("div", { className: css("vss-Header-TitleText", titleSize === 1 /* Large */ ? "title-l" : "title-m") }, title));
            }
            if (titleIconProps) {
                titleIconProps.className = css(titleIconProps.className, "vss-Header-Icon");
            }
            var commandBarComponent;
            if (commandBarItems || viewItems) {
                commandBarComponent = (React.createElement(HeaderCommandBar, { contextualMenuItems: commandBarItems, viewMenuItems: viewItems }));
            }
            return (React.createElement("div", { className: css("vss-Header flex-row", !!kicker && "kicker", titleSize === 1 /* Large */ && "large", className) },
                titleIconProps &&
                    React.createElement(VssIcon, tslib_1.__assign({}, titleIconProps)),
                React.createElement("div", { className: "flex-column" },
                    kicker && React.createElement("div", { className: "vss-Header-KickerText" }, kicker),
                    React.createElement("div", { className: "vss-Header-TitleRow flex-row" },
                        titleElement,
                        commandBarComponent))));
        });
    };
    return Header;
}(BaseComponent));
export { Header };

==> vss-ui-4.142.1.tgz: package/Components/Header/Header.js <==
import * as tslib_1 from "tslib";
import "../../FabricInit";
import * as React from "react";
import { HeaderCommandBar } from "../HeaderCommandBar/HeaderCommandBar";
import { VssIcon } from '../../VssIcon';
import { BaseComponent, css } from "office-ui-fabric-react/lib/Utilities";
import { TabProviderContext } from "../Tabs/TabProviderContext";
import { Observer } from '../../Observer';
var Header = /** @class */ (function (_super) {
    tslib_1.__extends(Header, _super);
    function Header() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Header.prototype.render = function () {
        var _this = this;
        return React.createElement(TabProviderContext.Consumer, null, function (tabProviderContext) {
            var _a = _this.props, title = _a.title, kicker = _a.kicker, titleSize = _a.titleSize, onRenderTitle = _a.onRenderTitle, onRenderCustomAreaContent = _a.onRenderCustomAreaContent, titleIconProps = _a.titleIconProps, viewItems = _a.viewItems, className = _a.className;
            var commandBarItems = _this.props.commandBarItems || tabProviderContext.commandBarItems;
            // Render the title as text, or override with custom rendering logic
            var titleElement;
            if (onRenderTitle) {
                titleElement = onRenderTitle();
            }
            else {
                titleElement = (React.createElement("div", { className: css("vss-Header-TitleText", titleSize === 1 /* Large */ ? "title-l" : "title-m") }, title));
            }
            if (titleIconProps) {
                titleIconProps.className = css(titleIconProps.className, "vss-Header-Icon");
            }
            var commandBarComponent;
            if (commandBarItems || viewItems) {
                commandBarComponent = (React.createElement(Observer, { contextualMenuItems: commandBarItems, viewMenuItems: _this.props.viewItems },
                    React.createElement(HeaderCommandBar, { contextualMenuItems: [], viewMenuItems: [] })));
            }
            return (React.createElement("div", { className: css("vss-Header flex-row flex-noshrink", !!kicker && "kicker", titleSize === 1 /* Large */ && "large", className) },
                titleIconProps &&
                    React.createElement(VssIcon, tslib_1.__assign({}, titleIconProps)),
                React.createElement("div", { className: "flex-column" },
                    kicker && React.createElement("div", { className: "vss-Header-KickerText" }, kicker),
                    React.createElement("div", { className: "vss-Header-TitleRow flex-row" },
                        titleElement,
                        commandBarComponent),
                    onRenderCustomAreaContent && React.createElement("div", null, onRenderCustomAreaContent()))));
        });
    };
    return Header;
}(BaseComponent));
export { Header };
